@@ -83,14 +83,14 @@ namespace Breeze
     }
 
     //__________________________________________________________
-    InternalSettingsList ExceptionListWidget::exceptions( void )
+    InternalSettingsList ExceptionListWidget::exceptions()
     {
         return model().get();
         setChanged( false );
     }
 
     //__________________________________________________________
-    void ExceptionListWidget::updateButtons( void )
+    void ExceptionListWidget::updateButtons()
     {
 
         bool hasSelection( !m_ui.exceptionListView->selectionModel()->selectedRows().empty() );
@@ -104,7 +104,7 @@ namespace Breeze
 
 
     //_______________________________________________________
-    void ExceptionListWidget::add( void )
+    void ExceptionListWidget::add()
     {
 
 
@@ -142,12 +142,11 @@ namespace Breeze
         }
 
         resizeColumns();
-        return;
 
     }
 
     //_______________________________________________________
-    void ExceptionListWidget::edit( void )
+    void ExceptionListWidget::edit()
     {
 
         // retrieve selection
@@ -181,12 +180,10 @@ namespace Breeze
 
         setChanged( true );
 
-        return;
-
     }
 
     //_______________________________________________________
-    void ExceptionListWidget::remove( void )
+    void ExceptionListWidget::remove()
     {
 
         // confirmation dialog
@@ -204,8 +201,6 @@ namespace Breeze
 
         setChanged( true );
 
-        return;
-
     }
 
     //_______________________________________________________
@@ -219,12 +214,11 @@ namespace Breeze
         InternalSettingsPtr exception( model().get( index ) );
         exception->setEnabled( !exception->enabled() );
         setChanged( true );
-        return;
 
     }
 
     //_______________________________________________________
-    void ExceptionListWidget::up( void )
+    void ExceptionListWidget::up()
     {
 
         InternalSettingsList selection( model().get( m_ui.exceptionListView->selectionModel()->selectedRows() ) );
@@ -265,12 +259,10 @@ namespace Breeze
 
         setChanged( true );
 
-        return;
-
     }
 
     //_______________________________________________________
-    void ExceptionListWidget::down( void )
+    void ExceptionListWidget::down()
     {
 
         InternalSettingsList selection( model().get( m_ui.exceptionListView->selectionModel()->selectedRows() ) );
@@ -317,12 +309,10 @@ namespace Breeze
 
         setChanged( true );
 
-        return;
-
     }
 
     //_______________________________________________________
-    void ExceptionListWidget::resizeColumns( void ) const
+    void ExceptionListWidget::resizeColumns() const
     {
         m_ui.exceptionListView->resizeColumnToContents( ExceptionModel::ColumnEnabled );
         m_ui.exceptionListView->resizeColumnToContents( ExceptionModel::ColumnType );
